### Name: eigenR2
### Title: Eigen-R2 for Dissecting Variation in High-dimensional Studies
### Aliases: eigenR2
### Keywords: misc

### ** Examples

  ## Not run: 
##D   ## Load the simulated data.
##D   ## The data set contains age, genotype and IDs for 50 arrays.
##D   ## The expression matrix is a 200 genes by 50 array matrix
##D   data(eigSdat)
##D   exp <- eigSdat$exp
##D   exp <- t(apply(exp, 1, function(x) x-mean(x)))
##D   varList <- eigSdat$varList
##D   age <- varList$age
##D   geno <- varList$geno
##D   ID <- varList$ID
##D 
##D   ## the eigen-R2 for variable "age"
##D   mod1 <- model.matrix(~1+age)
##D   eigenR2.age <- eigenR2(dat = exp, model = mod1) 
##D 
##D   ## the eigen-R2 for variable "age"
##D   ## adjust for small sample size
##D   eigenR2.age.adj <- eigenR2(dat=exp, model=mod1, adjust=TRUE)
##D   ## Or specifying the significance threshold of eigen-genes
##D   eigenR2.age.adj2 <- eigenR2(dat=exp, model=mod1, eigen.sig=0.01)
##D 
##D   ## the conditional eigen-R2 for "genotype" given "age"
##D   mod2 <- model.matrix(~1+age+as.factor(geno))
##D   eigenR2.g <- eigenR2(dat=exp, model=mod2, null.model=mod1)
##D 
##D   ## use "mod.fit.func" to specify the estimation function
##D   func1 <- function(y) {summary(lm(y~mod1))$r.squared}
##D   eigenR2.age2 <- eigenR2(dat=exp, mod.fit.func=func1)
##D 
##D   ## use linear mixed effect model to estimate R2s
##D   library(nlme)
##D   func2 <- function(y) {
##D       m1 <- lme(y~1+age+as.factor(geno), random=~1|ID)
##D       r2 <- 1-sum(resid(m1)^2)/sum((y-mean(y))^2)
##D       return(r2)
##D   }
##D   eigenR2.ag <- eigenR2(dat=exp, mod.fit.func=func2)
##D 
##D   ## Plot the information on the eigen-genes
##D   plot.eigenR2(eigenR2.ag)
##D   
## End(Not run)



